@@ -1,7 +1,7 @@
 parse_arg <- function(x){
 
   #special for json obj
-  if(is(x, "AsIs")){
+  if(inherits(x, "AsIs")){
     class(x) <- tail(class(x), -1);
     return(x);
   }
