@@ -1,12 +1,13 @@
 #doesn't work on windows. R_LIBS_USER will always be logged in user.
 userlibpath <- function(username, postfix=""){
   home <- homedir(username);
+  check_mode(home)
   homelib <- sub("~", home, Sys.getenv("R_LIBS_USER"), fixed=TRUE);
   homelib <- gsub("/+$", "", homelib);
   homelib <- paste(homelib, postfix, sep="");
   if(file.exists(homelib)){
     return(homelib);
-  } 
+  }
   
   #failed
   return("");
@@ -20,9 +21,15 @@ homedir <- function(username){
   }
   
   #second method
+  unixtools = "unixtools";
+  if(requireNamespace(unixtools, quietly = TRUE)){
+    return(getExportedValue(unixtools, "user.info")(username)$home)
+  }
+  
+  #third method
   if(file.exists("/etc/passwd")){
     out <- try(read.table("/etc/passwd", sep=":", row.names=1, as.is=TRUE));
-    if(!is(out, "try-error") && length(out) && nrow(out)){
+    if(!inherits(out, "try-error") && length(out) && nrow(out)){
       homelib <- out[username, "V6"];
       if(!is.na(homelib) && file.exists(homelib)){
         return(homelib)
@@ -31,4 +38,15 @@ homedir <- function(username){
   }
   
   stop("Could not find or access home directory of user ", username);
-}
\ No newline at end of file
+}
+
+check_mode <- function(path){
+  mode <- file.info(path)$mode
+  if(is.na(mode)){
+    stop("Failed to read mode for ", path)
+  }
+  # Check for r-x permission
+  if((mode & "005") < 5){
+    stop("Directory ", path, " is not readble. Try running: chmod +rx ", path)
+  }
+}
